Test results
============

This template ships a placeholder test report so documentation builds are stable.

.. literalinclude:: test_results.xml
   :language: xml

Coverage (optional):

.. literalinclude:: coverage_report.txt
   :language: text
